from a10sdk.common.A10BaseClass import A10BaseClass


class Router(A10BaseClass):
    
    """Class Description::
    Configure routing process.

    Class router supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ospf_list: {"minItems": 1, "items": {"type": "ospf"}, "uniqueItems": true, "array": [{"required": ["process-id"], "properties": {"distribute-internal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"di-cost": {"description": "Cost of route", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "di-area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true, "di-type": {"enum": ["lw4o6", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}, "di-area-ipv4": {"type": "string", "description": "OSPF area ID as a IP address format", "format": "ipv4-address"}}}]}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}, "protocol": {"enum": ["bgp", "connected", "floating-ip", "lw4o6", "ip-nat", "ip-nat-list", "isis", "ospf", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'lw4o6': LW4O6 Prefix; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'isis': ISO IS-IS; 'ospf': Open Shortest Path First (OSPF); 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "option": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}, "value": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}, "ospf-id": {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true}}]}, "default-metric": {"description": "Set metric of redistributed routes (Default metric)", "format": "number", "default": 20, "optional": true, "maximum": 16777214, "minimum": 1, "type": "number"}, "auto-cost-reference-bandwidth": {"description": "Use reference bandwidth method to assign OSPF cost (The reference bandwidth in terms of Mbits per second)", "format": "number", "default": 10000, "optional": true, "maximum": 4294967, "minimum": 1, "type": "number"}, "router-id": {"type": "object", "properties": {"value": {"type": "string", "description": "OSPF router-id in IPv4 address format", "format": "ipv4-address"}}}, "neighbor-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "cost": {"description": "OSPF cost for point-to-multipoint neighbor (Metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "address": {"type": "string", "description": "Neighbor address", "format": "ipv4-address"}}}]}, "ospf-1": {"type": "object", "properties": {"abr-type": {"type": "object", "properties": {"option": {"default": "cisco", "enum": ["cisco", "ibm", "shortcut", "standard"], "type": "string", "description": "'cisco': Alternative ABR, Cisco implementation (RFC3509); 'ibm': Alternative ABR, IBM implementation (RFC3509); 'shortcut': Shortcut ABR; 'standard': Standard behavior (RFC2328); ", "format": "enum"}}}}}, "host-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "host-address": {"type": "string", "description": "Host address", "format": "ipv4-address"}, "area-cfg": {"type": "object", "properties": {"area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "cost": {"description": "Cost of host", "format": "number", "default": 0, "maximum": 65535, "minimum": 0, "type": "number"}, "area-ipv4": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}}}}}]}, "log-adjacency-changes-cfg": {"type": "object", "properties": {"state": {"enum": ["detail", "disable"], "type": "string", "description": "'detail': Log changes in adjacency state; 'disable': Disable logging; ", "format": "enum"}}}, "area-list": {"minItems": 1, "items": {"type": "area"}, "uniqueItems": true, "array": [{"required": ["area-ipv4", "area-num"], "properties": {"nssa-cfg": {"type": "object", "properties": {"no-redistribution": {"default": 0, "type": "number", "description": "No redistribution into this NSSA area", "format": "flag"}, "translator-role": {"default": "candidate", "enum": ["always", "candidate", "never"], "type": "string", "description": "'always': Translate always; 'candidate': Candidate for translator (default); 'never': Do not translate; ", "format": "enum"}, "metric": {"description": "OSPF default metric (OSPF metric)", "format": "number", "default": 1, "maximum": 16777214, "minimum": 0, "type": "number"}, "nssa": {"default": 0, "type": "number", "description": "Specify a NSSA area", "format": "flag"}, "default-information-originate": {"default": 0, "type": "number", "description": "Originate Type 7 default into NSSA area", "format": "flag"}, "no-summary": {"default": 0, "type": "number", "description": "Do not send summary LSA into NSSA", "format": "flag"}, "metric-type": {"description": "OSPF metric type (OSPF metric type for default routes)", "format": "number", "default": 2, "maximum": 2, "minimum": 1, "type": "number"}}}, "filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "plist-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "acl-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by access-list (Name of an access-list)", "format": "string"}, "plist-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by prefix-list (Name of an IP prefix-list)", "format": "string"}, "filter-list": {"default": 0, "type": "number", "description": "Filter networks between OSPF areas", "format": "flag"}, "optional": true}}]}, "area-ipv4": {"optional": false, "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "virtual-link-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-key": {"description": "Set message digest key (Key ID)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "virtual-link-authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "virtual-link-ip-addr": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "virtual-link-auth-type": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use null authentication; ", "format": "enum"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Set authentication key (Authentication key (8 chars))", "format": "string-rlx"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "md5": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Use MD5 algorithm (Authentication key (16 chars))", "format": "string-rlx"}}}]}, "stub-cfg": {"type": "object", "properties": {"stub": {"default": 0, "type": "number", "description": "Configure OSPF area as stub", "format": "flag"}, "no-summary": {"default": 0, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}}}, "shortcut": {"description": "'default': Set default shortcutting behavior; 'disable': Disable shortcutting through the area; 'enable': Enable shortcutting through the area; ", "format": "enum", "default": "default", "type": "string", "enum": ["default", "disable", "enable"], "optional": true}, "auth-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "message-digest": {"default": 0, "type": "number", "description": "Use message-digest authentication", "format": "flag"}}}, "range-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-range-prefix": {"type": "string", "description": "Area range for IPv4 prefix", "format": "ipv4-cidr"}, "optional": true, "option": {"default": "advertise", "enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}}}]}, "default-cost": {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}, "area-num": {"description": "OSPF area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/router/ospf/{process-id}/area/{area-ipv4}+{area-num}"}, "maximum-area": {"description": "Maximum number of OSPF area (OSPF area limit)", "format": "number", "type": "number", "maximum": 4294967294, "minimum": 1, "optional": true}, "summary-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"summary-address": {"type": "string", "description": "Configure IP address summaries (Summary prefix)", "format": "ipv4-cidr"}, "not-advertise": {"default": 0, "type": "number", "description": "Suppress routes that match the prefix", "format": "flag"}, "tag": {"description": "Set tag (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true}}]}, "rfc1583-compatible": {"default": 0, "optional": true, "type": "number", "description": "Compatible with RFC 1583", "format": "flag"}, "max-concurrent-dd": {"description": "Maximum number allowed to process DD concurrently (Number of DD process)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "process-id": {"description": "OSPF process ID", "format": "number", "default": 0, "optional": false, "maximum": 65535, "minimum": 0, "type": "number"}, "passive-interface": {"type": "object", "properties": {"eth-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true, "eth-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}}}]}, "ve-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}}}]}, "trunk-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"trunk-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}}}]}, "loopback-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"loopback-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}, "lif-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"lif": {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}, "optional": true, "lif-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}}}]}}}, "default-information": {"type": "object", "properties": {"always": {"default": 0, "type": "number", "description": "Always advertise default route", "format": "flag"}, "metric": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "originate": {"default": 0, "type": "number", "description": "Distribute a default route", "format": "flag"}, "metric-type": {"description": "OSPF metric type for default routes", "format": "number", "default": 2, "maximum": 2, "minimum": 1, "type": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}}}, "overflow": {"type": "object", "properties": {"database": {"type": "object", "properties": {"count": {"description": "Maximum number of LSAs", "format": "number", "default": 4294967294, "maximum": 4294967294, "minimum": 0, "type": "number"}, "recovery-time": {"description": "Time to recover (0 not recover)", "format": "number", "default": 0, "maximum": 65535, "minimum": 0, "type": "number"}, "limit": {"default": "hard", "enum": ["hard", "soft"], "type": "string", "description": "'hard': Hard limit: Instance will be shutdown if exceeded; 'soft': Soft limit: Warning will be given if exceeded; ", "format": "enum"}, "db-external": {"description": "Maximum number of LSAs", "format": "number", "default": 2147483647, "maximum": 2147483647, "minimum": 0, "type": "number"}}}}}, "bfd-all-interfaces": {"default": 0, "optional": true, "type": "number", "description": "Enable BFD on all interfaces", "format": "flag"}, "distance": {"type": "object", "properties": {"distance-ospf": {"type": "object", "properties": {"distance-external": {"description": "External routes (Distance for external routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "distance-intra-area": {"description": "Intra-area routes (Distance for intra-area routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "distance-inter-area": {"description": "Inter-area routes (Distance for inter-area routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}, "distance-value": {"description": "OSPF Administrative distance", "format": "number", "default": 110, "maximum": 255, "minimum": 1, "type": "number"}}}, "redistribute": {"type": "object", "properties": {"redist-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "lw4o6", "isis", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'lw4o6': LW4O6 Prefix; 'isis': ISO IS-IS; 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "metric": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "tag": {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true, "metric-type": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}, "ospf-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "tag-ospf": {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "process-id": {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "route-map-ospf": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "metric-ospf": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "ospf": {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}, "metric-type-ospf": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}, "ip-nat-floating-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-nat-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}, "optional": true, "ip-nat-prefix": {"type": "string", "description": "Address", "format": "ipv4-cidr"}}}]}, "vip": {"default": 0, "type": "number", "description": "Virtual IP (VIP)", "format": "flag"}, "tag-ip-nat": {"type": "number", "description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "format": "number"}, "ip-nat": {"default": 0, "type": "number", "description": "IP-NAT", "format": "flag"}, "metric-ip-nat": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map-ip-nat": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "vip-floating-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vip-address": {"type": "string", "description": "Address", "format": "ipv4-address"}, "vip-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}}}]}, "metric-type-ip-nat": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}, "vip-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric-type-vip": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}, "tag-vip": {"type": "number", "description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "format": "number"}, "metric-vip": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map-vip": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "type-vip": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}}}]}}}, "network-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"network-area": {"type": "object", "properties": {"instance-value": {"description": "Instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "network-area-ipv4": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "network-area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}, "network-ipv4": {"type": "string", "description": "Network number", "format": "ipv4-address"}, "network-ipv4-cidr": {"type": "string", "description": "OSPF network prefix", "format": "ipv4-cidr"}, "network-ipv4-mask": {"type": "string", "description": "OSPF wild card bits", "format": "ipv4-rev-netmask"}, "optional": true}}]}, "timers": {"type": "object", "properties": {"spf": {"type": "object", "properties": {"exp": {"type": "object", "properties": {"max-delay": {"description": "Maximum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}, "min-delay": {"description": "Minimum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}}}}}}}, "ha-standby-extra-cost": {"description": "Extra ospf cost when there is any standby HA group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/ospf/{process-id}"}
    :param bgp_list: {"minItems": 1, "items": {"type": "bgp"}, "uniqueItems": true, "array": [{"required": ["as-number"], "properties": {"distance": {"type": "object", "properties": {"ext-routes-dist": {"description": "Distance for routes external to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "src-prefix": {"type": "string", "description": "IP source prefix", "format": "ipv4-cidr"}, "int-routes-dist": {"description": "Distance for routes internal to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "acl-str": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}, "admin-distance": {"description": "Define an administrative distance", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "local-routes-dist": {"description": "Distance for local routes", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}, "redistribute": {"type": "object", "properties": {"ip-nat-list-cfg": {"type": "object", "properties": {"ip-nat-list": {"default": 0, "type": "number", "description": "IP NAT list", "format": "flag"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}}}, "lw4o6-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "lw4o6": {"default": 0, "type": "number", "description": "LW4O6 Prefix", "format": "flag"}}}, "connected-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "connected": {"default": 0, "type": "number", "description": "Connected", "format": "flag"}}}, "ip-nat-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "ip-nat": {"default": 0, "type": "number", "description": "IP NAT", "format": "flag"}}}, "floating-ip-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "floating-ip": {"default": 0, "type": "number", "description": "Floating IP", "format": "flag"}}}, "isis-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "isis": {"default": 0, "type": "number", "description": "ISO IS-IS", "format": "flag"}}}, "vip": {"type": "object", "properties": {"only-not-flagged-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "only-not-flagged": {"default": 0, "type": "number", "description": "Only not flagged", "format": "flag"}}}, "only-flagged-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "only-flagged": {"default": 0, "type": "number", "description": "Selected Virtual IP (VIP)", "format": "flag"}}}}}, "rip-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "rip": {"default": 0, "type": "number", "description": "Routing Information Protocol (RIP)", "format": "flag"}}}, "ospf-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "ospf": {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}}}, "static-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "static": {"default": 0, "type": "number", "description": "Static routes", "format": "flag"}}}}}, "originate": {"default": 0, "optional": true, "type": "number", "description": "Distribute a default route", "format": "flag"}, "aggregate-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"as-set": {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}, "summary-only": {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}, "optional": true, "aggregate-address": {"type": "string", "description": "Configure BGP aggregate entries (Aggregate prefix)", "format": "ipv4-cidr"}}}]}, "as-number": {"description": "AS number", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": false}, "auto-summary": {"default": 0, "optional": true, "type": "number", "description": "Enable automatic network number summarization", "format": "flag"}, "bgp": {"type": "object", "properties": {"enforce-first-as": {"default": 0, "type": "number", "description": "Enforce the first AS for EBGP routes", "format": "flag"}, "scan-time": {"description": "Configure background scan interval (Scan interval (sec) [Default:60 Disable:0])", "format": "number", "default": 60, "maximum": 60, "minimum": 0, "type": "number"}, "router-id": {"type": "string", "description": "Override current router identifier (peers will reset) (Manually configured router identifier)", "format": "ipv4-address"}, "log-neighbor-changes": {"default": 0, "type": "number", "description": "Log neighbor up/down and reset reason", "format": "flag"}, "deterministic-med": {"default": 0, "type": "number", "description": "Pick the best-MED path among paths advertised from the neighboring AS", "format": "flag"}, "fast-external-failover": {"default": 1, "type": "number", "description": "Immediately reset session if a link to a directly connected external peer goes down", "format": "flag"}, "local-preference-value": {"description": "Configure default local preference value", "format": "number", "default": 100, "maximum": 4294967295, "minimum": 0, "type": "number"}, "nexthop-trigger-count": {"description": "BGP nexthop-tracking status (count)", "format": "number", "default": 0, "maximum": 127, "minimum": 0, "type": "number"}, "dampening-cfg": {"type": "object", "properties": {"dampening-max-supress": {"description": "Maximum duration to suppress a stable route(minutes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "dampening": {"default": 0, "type": "number", "description": "Enable route-flap dampening", "format": "flag"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route-map to specify criteria for dampening (Route-map name)", "format": "string"}, "dampening-penalty": {"description": "Un-reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}, "dampening-half-time": {"description": "Reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}, "dampening-supress": {"description": "Value to start suppressing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}, "dampening-reuse": {"description": "Value to start reusing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}}}, "always-compare-med": {"default": 0, "type": "number", "description": "Allow comparing MED from different neighbors", "format": "flag"}, "bestpath-cfg": {"type": "object", "properties": {"ignore": {"default": 0, "type": "number", "description": "Ignore as-path length in selecting a route", "format": "flag"}, "remove-send-med": {"default": 0, "type": "number", "description": "To remove send MED attribute", "format": "flag"}, "remove-recv-med": {"default": 0, "type": "number", "description": "To remove rcvd MED attribute", "format": "flag"}, "compare-routerid": {"default": 0, "type": "number", "description": "Compare router-id for identical EBGP paths", "format": "flag"}, "missing-as-worst": {"default": 0, "type": "number", "description": "Treat missing MED as the least preferred one", "format": "flag"}}}}}, "maximum-paths-value": {"description": "Supported BGP multipath numbers", "format": "number", "default": 1, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "synchronization": {"default": 0, "optional": true, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}, "timers": {"type": "object", "properties": {"bgp-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "maximum": 65535, "minimum": 0, "type": "number"}, "bgp-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "maximum": 65535, "minimum": 0, "type": "number"}}}, "neighbor": {"type": "object", "properties": {"peer-group-neighbor-list": {"minItems": 1, "items": {"type": "peer-group-neighbor"}, "uniqueItems": true, "array": [{"required": ["peer-group"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "default-originate": {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "peer-group": {"description": "Neighbor tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "peer-group-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "disallow-infinite-holdtime": {"default": 0, "optional": true, "type": "number", "description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "peer-group-key": {"default": 0, "optional": true, "type": "number", "description": "Configure peer-group", "format": "flag"}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/peer-group-neighbor/{peer-group}"}, "ipv6-neighbor-list": {"minItems": 1, "items": {"type": "ipv6-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv6"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "bfd-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-type": {"optional": true, "enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': md5; 'meticulous-md5': meticulous-md5; 'meticulous-sha1': meticulous-sha1; 'sha1': sha1; 'simple': simple;  (Keyed MD5/Meticulous Keyed MD5/Meticulous Keyed SHA1/Keyed SHA1/Simple Password)", "format": "enum"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "multihop": {"default": 0, "optional": true, "type": "number", "description": "Enable multihop", "format": "flag"}, "default-originate": {"description": "Originate default route to this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "nbr-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "bfd": {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"description": "Disable the next hop calculation for this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "peer-group-name", "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-id": {"description": "Key ID", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "neighbor-ipv6": {"optional": false, "type": "string", "description": "Neighbor IPv6 address", "format": "ipv6-address"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "bfd-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "disallow-infinite-holdtime": {"description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "not-list": ["advertisement-interval", "as-origination-interval", "default-originate", "disallow-infinite-holdtime", "next-hop-self", "timers", "unsuppress-map"], "optional": true, "maxLength": 128, "type": "string"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/ipv6-neighbor/{neighbor-ipv6}"}, "ipv4-neighbor-list": {"minItems": 1, "items": {"type": "ipv4-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv4"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "bfd-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-type": {"optional": true, "enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': md5; 'meticulous-md5': meticulous-md5; 'meticulous-sha1': meticulous-sha1; 'sha1': sha1; 'simple': simple;  (Keyed MD5/Meticulous Keyed MD5/Meticulous Keyed SHA1/Keyed SHA1/Simple Password)", "format": "enum"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "multihop": {"default": 0, "optional": true, "type": "number", "description": "Enable multihop", "format": "flag"}, "default-originate": {"description": "Originate default route to this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "nbr-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "bfd": {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"description": "Disable the next hop calculation for this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "peer-group-name", "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-id": {"description": "Key ID", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "neighbor-ipv4": {"optional": false, "type": "string", "description": "Neighbor address", "format": "ipv4-address"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "bfd-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "disallow-infinite-holdtime": {"description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "not-list": ["advertisement-interval", "as-origination-interval", "default-originate", "disallow-infinite-holdtime", "next-hop-self", "timers", "unsuppress-map"], "optional": true, "maxLength": 128, "type": "string"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/ipv4-neighbor/{neighbor-ipv4}"}}}, "address-family": {"type": "object", "properties": {"ipv6": {"type": "object", "properties": {"distance": {"type": "object", "properties": {"distance-local": {"description": "Distance for local routes", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "distance-int": {"description": "Distance for routes internal to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "distance-ext": {"description": "Distance for routes external to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}, "redistribute": {"type": "object", "properties": {"ip-nat-list-cfg": {"type": "object", "properties": {"ip-nat-list": {"default": 0, "type": "number", "description": "IP NAT list", "format": "flag"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}}}, "lw4o6-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "lw4o6": {"default": 0, "type": "number", "description": "LW4O6 Prefix", "format": "flag"}}}, "nat64-cfg": {"type": "object", "properties": {"nat64": {"default": 0, "type": "number", "description": "NAT64 Prefix", "format": "flag"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}}}, "connected-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "connected": {"default": 0, "type": "number", "description": "Connected", "format": "flag"}}}, "ip-nat-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "ip-nat": {"default": 0, "type": "number", "description": "IP NAT", "format": "flag"}}}, "floating-ip-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "floating-ip": {"default": 0, "type": "number", "description": "Floating IP", "format": "flag"}}}, "isis-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "isis": {"default": 0, "type": "number", "description": "ISO IS-IS", "format": "flag"}}}, "vip": {"type": "object", "properties": {"only-not-flagged-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "only-not-flagged": {"default": 0, "type": "number", "description": "Only not flagged", "format": "flag"}}}, "only-flagged-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "only-flagged": {"default": 0, "type": "number", "description": "Selected Virtual IP (VIP)", "format": "flag"}}}}}, "rip-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "rip": {"default": 0, "type": "number", "description": "Routing Information Protocol (RIP)", "format": "flag"}}}, "ospf-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "ospf": {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}}}, "static-cfg": {"type": "object", "properties": {"route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "static": {"default": 0, "type": "number", "description": "Static routes", "format": "flag"}}}}}, "aggregate-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"as-set": {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}, "summary-only": {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}, "optional": true, "aggregate-address": {"type": "string", "description": "Configure BGP aggregate entries (Aggregate IPv6 prefix)", "format": "ipv6-address-plen"}}}]}, "originate": {"default": 0, "type": "number", "description": "Distribute an IPv6 default route", "format": "flag"}, "auto-summary": {"default": 0, "type": "number", "description": "Enable automatic network number summarization", "format": "flag"}, "bgp": {"type": "object", "properties": {"dampening-max-supress": {"description": "Maximum duration to suppress a stable route(minutes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "dampening": {"default": 0, "type": "number", "description": "Enable route-flap dampening", "format": "flag"}, "dampening-half": {"description": "Reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}, "dampening-start-reuse": {"description": "Value to start reusing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route-map to specify criteria for dampening (Route-map name)", "format": "string"}, "dampening-start-supress": {"description": "Value to start suppressing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}, "dampening-unreachability": {"description": "Un-reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}}}, "maximum-paths-value": {"description": "Supported BGP multipath numbers", "format": "number", "default": 1, "maximum": 10, "minimum": 1, "type": "number"}, "synchronization": {"default": 0, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}, "neighbor": {"type": "object", "properties": {"peer-group-neighbor-list": {"minItems": 1, "items": {"type": "peer-group-neighbor"}, "uniqueItems": true, "array": [{"required": ["peer-group"], "properties": {"maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "activate": {"default": 0, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "next-hop-self": {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "peer-group": {"description": "Neighbor tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "default-originate": {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/address-family/ipv6/neighbor/peer-group-neighbor/{peer-group}"}, "ipv6-neighbor-list": {"minItems": 1, "items": {"type": "ipv6-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv6"], "properties": {"maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "neighbor-ipv6": {"optional": false, "type": "string", "description": "Neighbor IPv6 address", "format": "ipv6-address"}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "next-hop-self": {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "default-originate": {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "activate": {"default": 0, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/address-family/ipv6/neighbor/ipv6-neighbor/{neighbor-ipv6}"}, "ipv4-neighbor-list": {"minItems": 1, "items": {"type": "ipv4-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv4"], "properties": {"maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "neighbor-ipv4": {"optional": false, "type": "string", "description": "Neighbor address", "format": "ipv4-address"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "next-hop-self": {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "default-originate": {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "activate": {"default": 0, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/address-family/ipv6/neighbor/ipv4-neighbor/{neighbor-ipv4}"}}}, "network": {"type": "object", "properties": {"ipv6-network-list": {"minItems": 1, "items": {"type": "ipv6-network"}, "uniqueItems": true, "array": [{"required": ["network-ipv6"], "properties": {"network-ipv6": {"optional": false, "type": "string", "description": "Specify a network to announce via BGP", "format": "ipv6-address-plen"}, "backdoor": {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}, "route-map": {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "description": {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}, "comm-value": {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/address-family/ipv6/network/ipv6-network/{network-ipv6}"}, "synchronization": {"type": "object", "properties": {"network-synchronization": {"default": 0, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}}}}}}}}}, "network": {"type": "object", "properties": {"synchronization": {"type": "object", "properties": {"network-synchronization": {"default": 0, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}}}, "ip-mask-list": {"minItems": 1, "items": {"type": "ip-mask"}, "uniqueItems": true, "array": [{"required": ["network-ipv4", "mask"], "properties": {"description": {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}, "route-map": {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "mask": {"optional": false, "type": "string", "description": "Specify network mask (Network mask, e.g., 255.255.0.0)", "format": "ipv4-netmask"}, "comm-value": {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}, "backdoor": {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}, "network-ipv4": {"optional": false, "type": "string", "description": "IP prefix", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/network/ip-mask/{network-ipv4}+{mask}"}, "ip-cidr-list": {"minItems": 1, "items": {"type": "ip-cidr"}, "uniqueItems": true, "array": [{"required": ["network-ipv4-cidr"], "properties": {"backdoor": {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}, "route-map": {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "network-ipv4-cidr": {"optional": false, "type": "string", "description": "Specify network mask", "format": "ipv4-cidr"}, "description": {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}, "comm-value": {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/network/ip-cidr/{network-ipv4-cidr}"}}}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}"}
    :param isis_list: {"minItems": 1, "items": {"type": "isis"}, "uniqueItems": true, "array": [{"required": ["tag"], "properties": {"domain-password-cfg": {"type": "object", "properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Set the authentication password for a routing domain (Routing domain password)", "format": "string-rlx"}, "authenticate": {"type": "object", "properties": {"snp": {"enum": ["send-only", "validate"], "type": "string", "description": "'send-only': Send but do not check PDUs on receiving; 'validate': Send and check PDUs on receiving; ", "format": "enum"}}}}}, "max-lsp-lifetime": {"description": "Set maximum LSP lifetime (Maximum LSP lifetime in seconds)", "format": "number", "default": 1200, "optional": true, "maximum": 65535, "minimum": 350, "type": "number"}, "tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "lsp-refresh-interval": {"description": "Set LSP refresh interval (LSP refresh time in seconds)", "format": "number", "default": 900, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "set-overload-bit-cfg": {"type": "object", "properties": {"suppress-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"suppress": {"enum": ["external", "interlevel"], "type": "string", "description": "'external': If overload-bit set, don't advertise IP prefixes learned from other protocols; 'interlevel': If overload-bit set, don't advertise IP prefixes learned from another ISIS level; ", "format": "enum"}, "optional": true}}]}, "set-overload-bit": {"default": 0, "type": "number", "description": "Signal other touers not to use us in SPF", "format": "flag"}, "on-startup": {"type": "object", "properties": {"delay": {"description": "Time in seconds to advertise ourself as overloaded after reboot", "format": "number", "maximum": 86400, "minimum": 5, "not": "wait-for-bgp", "type": "number"}, "wait-for-bgp": {"default": 0, "not": "delay", "type": "number", "description": "Let BGP decide when to unset the overload bit", "format": "flag"}}}}}, "net-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"net": {"minLength": 1, "maxLength": 63, "type": "string", "description": "A Network Entity Title for this process (XX.XXXX. ... .XXXX.XX  Network entity title (NET))", "format": "nasp-string"}, "optional": true}}]}, "bfd": {"optional": true, "enum": ["all-interfaces"], "type": "string", "description": "'all-interfaces': Enable BFD on all interfaces; ", "format": "enum"}, "metric-style-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "type": {"default": "narrow", "enum": ["narrow", "wide", "transition", "narrow-transition", "wide-transition"], "type": "string", "description": "'narrow': Use old style of TLVs with narrow metric; 'wide': Use new style of TLVs to carry wider metric; 'transition': Send and accept both styles of TLVs during transition; 'narrow-transition': Send old style of TLVs with narrow metric with accepting both styles of TLVs; 'wide-transition': Send new style of TLVs to carry wider metric with accepting both styles of TLVs; ", "format": "enum"}, "level": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Level-1 only; 'level-1-2': Level-1-2; 'level-2': Level-2 only; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Authentication mode; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "ignore-lsp-errors": {"default": 0, "optional": true, "type": "number", "description": "Ignore LSPs with bad checksums", "format": "flag"}, "log-adjacency-changes-cfg": {"type": "object", "properties": {"state": {"enum": ["detail", "disable"], "type": "string", "description": "'detail': Log changes in adjacency state; 'disable': Disable logging; ", "format": "enum"}}}, "spf-interval-exp-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"max": {"description": "Maximum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}, "optional": true, "min": {"description": "Minimum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}}}]}, "passive-interface-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"lif": {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}, "summary-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"prefix": {"type": "string", "description": "IP network prefix", "format": "ipv4-cidr"}, "optional": true, "level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}}}]}, "adjacency-check": {"default": 1, "optional": true, "type": "number", "description": "Check ISIS neighbor protocol support", "format": "flag"}, "default-information": {"optional": true, "enum": ["originate"], "type": "string", "description": "'originate': Distribute a default route; ", "format": "enum"}, "address-family": {"type": "object", "properties": {"ipv6": {"type": "object", "properties": {"distance": {"description": "ISIS Administrative Distance (Distance value)", "format": "number", "default": 115, "maximum": 255, "minimum": 1, "type": "number"}, "redistribute": {"type": "object", "properties": {"vip-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': IS-IS level-1 routes only; 'level-1-2': IS-IS level-1 and level-2 routes; 'level-2': IS-IS level-2 routes only; ", "format": "enum"}, "type": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}, "metric": {"description": "Metric for redistributed routes (IS-IS default metric)", "format": "number", "default": 0, "maximum": 4261412864, "minimum": 0, "type": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "metric-type": {"default": "internal", "enum": ["external", "internal"], "type": "string", "description": "'external': Set IS-IS External metric type; 'internal': Set IS-IS Internal metric type; ", "format": "enum"}}}]}, "redist-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': IS-IS level-1 routes only; 'level-1-2': IS-IS level-1 and level-2 routes; 'level-2': IS-IS level-2 routes only; ", "format": "enum"}, "type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "ip-nat", "lw4o6", "nat64", "ospf", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'ip-nat': IP NAT; 'lw4o6': LW4O6 Prefix; 'nat64': NAT64 Prefix; 'ospf': Open Shortest Path First (OSPF); 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "metric": {"description": "Metric for redistributed routes (IS-IS default metric)", "format": "number", "default": 0, "maximum": 4261412864, "minimum": 0, "type": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "metric-type": {"default": "internal", "enum": ["external", "internal"], "type": "string", "description": "'external': Set IS-IS External metric type; 'internal': Set IS-IS Internal metric type; ", "format": "enum"}}}]}, "isis": {"type": "object", "properties": {"level-2-from": {"type": "object", "properties": {"into-2": {"type": "object", "properties": {"distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Select routes (Access-list name)", "format": "string"}, "level-1": {"default": 0, "type": "number", "description": "Inter-area routes into level-2", "format": "flag"}}}}}, "level-1-from": {"type": "object", "properties": {"into-1": {"type": "object", "properties": {"level-2": {"default": 0, "type": "number", "description": "Inter-area routes into level-2", "format": "flag"}, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Select routes (Access-list name)", "format": "string"}}}}}}}}}, "multi-topology-cfg": {"type": "object", "properties": {"multi-topology": {"default": 0, "type": "number", "description": "Enable multi-topology mode", "format": "flag"}, "level-transition": {"default": 0, "type": "number", "description": "Accept and generate both IS-IS IPv6 and Multi-topology IPV6 TLVs", "format": "flag"}, "transition": {"default": 0, "not": "level", "type": "number", "description": "Accept and generate both IS-IS IPv6 and Multi-topology IPV6 TLVs", "format": "flag"}, "level": {"not": "transition", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Level-1 only; 'level-1-2': Level-1-2; 'level-2': Level-2 only; ", "format": "enum"}}}, "adjacency-check": {"default": 1, "type": "number", "description": "Check ISIS neighbor protocol support", "format": "flag"}, "summary-prefix-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "optional": true, "level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}}}]}, "default-information": {"enum": ["originate"], "type": "string", "description": "'originate': Distribute a default route; ", "format": "enum"}}}}}, "redistribute": {"type": "object", "properties": {"vip-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': IS-IS level-1 routes only; 'level-1-2': IS-IS level-1 and level-2 routes; 'level-2': IS-IS level-2 routes only; ", "format": "enum"}, "type": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}, "metric": {"description": "Metric for redistributed routes (IS-IS default metric)", "format": "number", "default": 0, "maximum": 4261412864, "minimum": 0, "type": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "metric-type": {"default": "internal", "enum": ["external", "internal"], "type": "string", "description": "'external': Set IS-IS External metric type; 'internal': Set IS-IS Internal metric type; ", "format": "enum"}}}]}, "redist-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': IS-IS level-1 routes only; 'level-1-2': IS-IS level-1 and level-2 routes; 'level-2': IS-IS level-2 routes only; ", "format": "enum"}, "type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "ip-nat", "lw4o6", "ospf", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'ip-nat': IP NAT; 'lw4o6': LW4O6 Prefix; 'ospf': Open Shortest Path First (OSPF); 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "metric": {"description": "Metric for redistributed routes (IS-IS default metric)", "format": "number", "default": 0, "maximum": 4261412864, "minimum": 0, "type": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "metric-type": {"default": "internal", "enum": ["external", "internal"], "type": "string", "description": "'external': Set IS-IS External metric type; 'internal': Set IS-IS Internal metric type; ", "format": "enum"}}}]}, "isis": {"type": "object", "properties": {"level-2-from": {"type": "object", "properties": {"into-2": {"type": "object", "properties": {"distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Select routes (Access-list name)", "format": "string"}, "level-1": {"default": 0, "type": "number", "description": "Inter-area routes into level-2", "format": "flag"}}}}}, "level-1-from": {"type": "object", "properties": {"into-1": {"type": "object", "properties": {"level-2": {"default": 0, "type": "number", "description": "Inter-area routes into level-2", "format": "flag"}, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Select routes (Access-list name)", "format": "string"}}}}}}}}}, "area-password-cfg": {"type": "object", "properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for an area (Area password)", "format": "string-rlx"}, "authenticate": {"type": "object", "properties": {"snp": {"enum": ["send-only", "validate"], "type": "string", "description": "'send-only': Send but do not check PDUs on receiving; 'validate': Send and check PDUs on receiving; ", "format": "enum"}}}}}, "lsp-gen-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"interval": {"description": "Minimum interval in seconds", "format": "number", "default": 30, "maximum": 120, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}}}]}, "is-type": {"description": "'level-1': Act as a station router only; 'level-1-2': Act as both a station router and an area router; 'level-2-only': Act as an area router only; ", "format": "enum", "default": "level-1", "type": "string", "enum": ["level-1", "level-1-2", "level-2-only"], "optional": true}, "protocol-topology": {"default": 0, "optional": true, "type": "number", "description": "Protocol Topology", "format": "flag"}, "distance-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "ISIS Administrative Distance (Distance value)", "format": "number", "default": 115, "maximum": 255, "minimum": 1, "type": "number"}, "System-ID": {"minLength": 1, "maxLength": 128, "type": "string", "description": "System-ID in XXXX.XXXX.XXXX", "format": "string"}, "optional": true, "acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}}}]}, "ha-standby-extra-cost": {"description": "Extra IS-IS metric when there is any standby ha group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/isis/{tag}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "router"
        self.a10_url="/axapi/v3/router"
        self.DeviceProxy = ""
        self.ospf_list = []
        self.log = {}
        self.rip = {}
        self.bgp_list = []
        self.ipv6 = {}
        self.isis_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


