from a10sdk.common.A10BaseClass import A10BaseClass


class Authentication(A10BaseClass):
    
    """Class Description::
    Configure AAM authentication settings.

    Class authentication supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param portal_list: {"minItems": 1, "items": {"type": "portal"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"logon-fail": {"type": "object", "properties": {"fail-msg-cfg": {"type": "object", "properties": {"fail-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}, "fail-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "fail-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "fail-msg": {"default": 0, "type": "number", "description": "Configure logon failure message in default logon fail page", "format": "flag"}, "fail-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon failure message (Default: Login Failed!!)", "format": "string-rlx"}, "fail-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}, "fail-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "fail-color-name": {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "fail-face": {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "welcome-msg-cfg": {"type": "object", "properties": {"wel-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}, "wel-color-name": {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "wel-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}, "wel-face": {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "wel-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "wel-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "wel-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "wel-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Deault: Try too many times.)", "format": "string-rlx"}, "welcome-msg": {"default": 0, "type": "number", "description": "Configure welcome message in default logon fail page", "format": "flag"}}}, "title-cfg": {"type": "object", "properties": {"title": {"default": 0, "type": "number", "description": "Configure title in default logon fail page", "format": "flag"}, "title-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "title-color-name": {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "title-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}, "title-face": {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "title-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}, "title-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "title-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}, "title-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "note-cfg": {"type": "object", "properties": {"note-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}, "note-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}, "note-face": {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "note-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "note-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "note-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "note": {"default": 0, "type": "number", "description": "Configure notes in default logon page", "format": "flag"}, "note-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}, "note-color-name": {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}, "logon": {"type": "object", "properties": {"action-url": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify form action URL in default logon page (Default: /logon.fo)", "format": "string-rlx"}, "password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password variable name in default logon page (Default: pwd)", "format": "string-rlx"}, "username-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in default logon page (Default: user)", "format": "string-rlx"}, "submit-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify submit button text in default logon page (Default: Log In)", "format": "string-rlx"}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "fail-msg-cfg": {"type": "object", "properties": {"fail-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}, "fail-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "fail-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "fail-msg": {"default": 0, "type": "number", "description": "Configure login failure message in default logon page", "format": "flag"}, "fail-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify login failure message (Default: Invalid username or password. Please try again.)", "format": "string-rlx"}, "fail-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}, "fail-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "fail-color-name": {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "fail-face": {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "password-cfg": {"type": "object", "properties": {"pass-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "pass-color-name", "type": "string"}, "pass-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "pass-color-name": {"not": "pass-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "pass-face": {"not": "pass-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "pass-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "pass-face", "type": "string"}, "pass-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "pass-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password text (Default: Password)", "format": "string-rlx"}, "pass-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "password": {"default": 0, "type": "number", "description": "Configure password text in default logon page", "format": "flag"}}}, "username-cfg": {"type": "object", "properties": {"username": {"default": 0, "type": "number", "description": "Configure username text in default logon page", "format": "flag"}, "user-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "user-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: User Name)", "format": "string-rlx"}, "user-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "user-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}, "user-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}, "user-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "user-face": {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "user-color-name": {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}, "logo-cfg": {"type": "object", "properties": {"logo": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logo image filename", "format": "string-rlx"}, "height": {"description": "Specify logo image height", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}, "width": {"description": "Specify logo image width", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}}}, "name": {"optional": false, "enum": ["default-portal"], "type": "string", "description": "'default-portal': Default portal configuration; ", "format": "enum"}, "change-password": {"type": "object", "properties": {"action-url": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify form action URL in default change password page (Default: /change.fo)", "format": "string-rlx"}, "new-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password variable name in default change password page (Default: cp_new_pwd)", "format": "string-rlx"}, "new-pwd-cfg": {"type": "object", "properties": {"new-password": {"default": 0, "type": "number", "description": "Configure new password text in default change password page", "format": "flag"}, "new-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "new-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "new-color-name": {"not": "new-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "new-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "new-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "new-color-name", "type": "string"}, "new-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password text (Default: New Password)", "format": "string-rlx"}, "new-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "new-face", "type": "string"}, "new-face": {"not": "new-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "submit-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify submit button text in default change password page (Default: Submit)", "format": "string"}, "welcome-msg-cfg": {"type": "object", "properties": {"wel-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}, "wel-color-name": {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "wel-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}, "wel-face": {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "wel-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "wel-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "wel-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "wel-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Default: Please change your password.)", "format": "string-rlx"}, "welcome-msg": {"default": 0, "type": "number", "description": "Configure welcome message in default change password page", "format": "flag"}}}, "confirm-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify confirm password variable name in default change password page (Default: cp_cfm_pwd)", "format": "string-rlx"}, "title-cfg": {"type": "object", "properties": {"title": {"default": 0, "type": "number", "description": "Configure title in default change password page", "format": "flag"}, "title-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "title-color-name": {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "title-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}, "title-face": {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "title-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}, "title-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "title-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}, "title-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "reset-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify reset button text in default change password page (Default: Reset)", "format": "string"}, "username-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in default change password page (Default: cp_usr)", "format": "string-rlx"}, "old-pwd-cfg": {"type": "object", "properties": {"old-face": {"not": "old-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "old-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "old-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "old-color-name", "type": "string"}, "old-password": {"default": 0, "type": "number", "description": "Configure old password text in default change password page", "format": "flag"}, "old-color-name": {"not": "old-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "old-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "old-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password text (Default: Old Password)", "format": "string-rlx"}, "old-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "old-face", "type": "string"}, "old-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "old-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password variable name in default change password page (Default: cp_old_pwd)", "format": "string-rlx"}, "cfm-pwd-cfg": {"type": "object", "properties": {"cfm-color-name": {"not": "cfm-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "cfm-face": {"not": "cfm-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "cfm-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "cfm-color-name", "type": "string"}, "cfm-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "cfm-face", "type": "string"}, "cfm-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "cfm-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "cfm-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify confirm password text (Default: Confirm New Password)", "format": "string-rlx"}, "confirm-password": {"default": 0, "type": "number", "description": "Configure confirm password text in default change password page", "format": "flag"}, "cfm-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}}}, "username-cfg": {"type": "object", "properties": {"username": {"default": 0, "type": "number", "description": "Configure username text in default change password page", "format": "flag"}, "user-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "user-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: Username)", "format": "string-rlx"}, "user-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "user-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}, "user-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}, "user-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "user-face": {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "user-color-name": {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}, "note-cfg": {"type": "object", "properties": {"note-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}, "note-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}, "note-face": {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "note-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "note-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "note-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "note": {"default": 0, "type": "number", "description": "Configure notes in default change password page", "format": "flag"}, "note-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}, "note-color-name": {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/portal/{name}"}
    :param service_group_list: {"minItems": 1, "items": {"type": "service-group"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "protocol": {"description": "'tcp': TCP AAM service; 'udp': UDP AAM service; ", "format": "enum", "type": "string", "enum": ["tcp", "udp"], "modify-not-allowed": 1, "optional": true}, "name": {"description": "Specify AAM service group name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "lb-method": {"optional": true, "enum": ["round-robin"], "type": "string", "description": "'round-robin': Round robin on server level; ", "format": "enum"}, "member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"member-priority": {"description": "Priority of Port in the Group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": true}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap"}, "member-state": {"description": "'enable': Enable member service port; 'disable': Disable member service port; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/service-group/{name}/member/{name}+{port}"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/service-group/{name}"}
    :param template_list: {"minItems": 1, "items": {"type": "template"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"logout-idle-timeout": {"description": "Specify idle logout time (Specify idle timeout in seconds, default is 300)", "format": "number", "default": 300, "optional": true, "maximum": 86400, "minimum": 1, "type": "number"}, "cookie-domain": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmn": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify domain scope for the authentication (ex: .a10networks.com)", "format": "string-rlx"}, "optional": true}}]}, "name": {"description": "Authentication template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "relay": {"description": "Specify authentication relay (Specify authentication relay template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/relay/http-basic/instance"}, "logon": {"description": "Specify authentication logon (Specify authentication logon template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/logon/form-based"}, "saml-sp": {"description": "Specify SAML service provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "logout-url": {"description": "Specify logout url (Specify logout url string)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "service-group": {"description": "Bind an authentication service group to this template (Specify authentication service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "server", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "server": {"description": "Specify authentication server (Specify authentication server template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "service-group", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap/instance"}, "cookie-domain-group": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmngrp": {"description": "Specify group id to join in the cookie-domain", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "optional": true}}]}, "log": {"description": "'use-partition-level-config': Use configuration of authentication-log enable command; 'enable': Enable authentication logs for this template; 'disable': Disable authentication logs for this template; ", "format": "enum", "default": "use-partition-level-config", "type": "string", "enum": ["use-partition-level-config", "enable", "disable"], "optional": true}, "account": {"description": "Specify AD domain account", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/account/kerberos-spn"}, "saml-idp": {"description": "Specify SAML identity provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "type": {"optional": true, "enum": ["saml", "standard"], "type": "string", "description": "'saml': SAML authentication template; 'standard': Standard authentication template; ", "format": "enum"}, "cookie-max-age": {"description": "Configure Max-Age for authentication session cookie (Configure Max-Age in seconds. Default is 604800 (1 week).)", "format": "number", "default": 604800, "optional": true, "maximum": 2592000, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/template/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "authentication"
        self.a10_url="/axapi/v3/aam/authentication"
        self.DeviceProxy = ""
        self.account = {}
        self.portal_list = []
        self.log = {}
        self.relay = {}
        self.saml = {}
        self.service_group_list = []
        self.server = {}
        self.template_list = []
        self.logon = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


